@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
- *  Copyright (C) 2004 Adam Hooper
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
+ *  Copyright © 2004 Adam Hooper
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-error-viewer-extension.c,v 1.28 2006/02/07 23:11:02 crispin Exp $
+ *  $Id: ephy-error-viewer-extension.c,v 1.30 2006/09/13 19:01:07 chpe Exp $
  */
 
 #include "config.h"
@@ -126,7 +126,7 @@ ephy_error_viewer_extension_get_type (void)
 GType
 ephy_error_viewer_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyErrorViewerExtensionClass),
 		NULL, /* base_init */
@@ -139,7 +139,7 @@ ephy_error_viewer_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_error_viewer_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_error_viewer_extension_iface_init,
 		NULL,
