@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004 Adam Hooper
+ *  Copyright © 2004 Adam Hooper
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ErrorViewerURICheckerObserver.cpp,v 1.12 2006/09/03 16:31:12 chpe Exp $
+ *  $Id: ErrorViewerURICheckerObserver.cpp,v 1.14 2006/09/13 19:01:08 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -45,10 +45,10 @@
 NS_IMPL_ISUPPORTS1(ErrorViewerURICheckerObserver, nsIRequestObserver)
 
 ErrorViewerURICheckerObserver::ErrorViewerURICheckerObserver()
+  : mNumLinksChecked (0)
+  , mNumLinksInvalid (0)
+  , mNumLinksTotal (0)
 {
-	mNumLinksTotal = 0;
-	mNumLinksChecked = 0;
-	mNumLinksInvalid = 0;
 }
                                                                                 
 ErrorViewerURICheckerObserver::~ErrorViewerURICheckerObserver()
