@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,17 +16,19 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-extensions-manager-ui-extension.c,v 1.7 2006/01/21 21:16:42 rslinckx Exp $
+ *  $Id: ephy-extensions-manager-ui-extension.c,v 1.11 2006/09/13 19:01:09 chpe Exp $
  */
 
 #include "config.h"
 
 #include "ephy-extensions-manager-ui-extension.h"
 #include "extensions-manager-ui.h"
-#include "ephy-debug.h"
 
 #include <epiphany/ephy-extension.h>
 
+#include "ephy-gui.h"
+#include "ephy-debug.h"
+
 #include <gmodule.h>
 
 #include <gtk/gtkaction.h>
@@ -57,6 +59,8 @@ typedef struct
 
 static void display_cb (GtkAction *action,
 			EphyWindow *window);
+static void help_cb    (GtkAction *action,
+			EphyWindow *window);
 
 static const GtkActionEntry action_entries [] =
 {
@@ -66,6 +70,13 @@ static const GtkActionEntry action_entries [] =
 	  NULL,
 	  N_("Load and unload extensions"),
 	  G_CALLBACK (display_cb) },
+	{ "ExtensionsManagerHelp",
+	  NULL,
+	  N_("_Extensions"),
+	  NULL,
+	  N_("Help about extensions"),
+	  G_CALLBACK (help_cb)
+	}
 };
 
 static GObjectClass *parent_class = NULL;
@@ -81,7 +92,7 @@ ephy_extensions_manager_ui_extension_get_type (void)
 GType
 ephy_extensions_manager_ui_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyExtensionsManagerUIExtensionClass),
 		NULL, /* base_init */
@@ -94,7 +105,7 @@ ephy_extensions_manager_ui_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_extensions_manager_ui_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_extensions_manager_ui_extension_iface_init,
 		NULL,
@@ -152,14 +163,27 @@ display_cb (GtkAction *action,
 
 	if (priv->dialog == NULL)
 	{
+		ExtensionsManagerUI **dialog;
+
 		priv->dialog = extensions_manager_ui_new ();
+		dialog = &priv->dialog;
 		g_object_add_weak_pointer (G_OBJECT (priv->dialog),
-					   (gpointer *) &priv->dialog);
+					   (gpointer *) dialog);
 	}
 
 	ephy_dialog_show (EPHY_DIALOG (priv->dialog));
 }
 
+static void
+help_cb (GtkAction *action,
+	 EphyWindow *window)
+{
+	ephy_gui_help_with_doc_id (GTK_WINDOW (window),
+				   "epiphany-extensions",
+				   "epiphany-extensions",
+				   "");
+}
+
 static void
 impl_attach_window (EphyExtension *ext,
 		    EphyWindow *window)
@@ -199,7 +223,9 @@ impl_attach_window (EphyExtension *ext,
 			       "ExtensionsManagerUISep2", NULL,
 			       GTK_UI_MANAGER_SEPARATOR, FALSE);
 
-	LOG ("EphyExtensionsManagerUIExtension attach_window");
+	gtk_ui_manager_add_ui (manager, ui_id, "/menubar/HelpMenu/HelpContentsMenu",
+			       "ExtensionsManagerHelp", "ExtensionsManagerHelp",
+			       GTK_UI_MANAGER_MENUITEM, FALSE);
 }
 
 static void
@@ -213,14 +239,12 @@ impl_detach_window (EphyExtension *ext,
 
 	data = (WindowData *) g_object_get_data (G_OBJECT (window),
 						 WINDOW_DATA_KEY);
-	g_return_if_fail (data != NULL);
+	g_assert (data != NULL);
 
 	gtk_ui_manager_remove_ui (manager, data->ui_id);
 	gtk_ui_manager_remove_action_group (manager, data->action_group);
 
 	g_object_set_data (G_OBJECT (window), WINDOW_DATA_KEY, NULL);
-
-	LOG ("EphyExtensionsManagerUIExtension detach_window");
 }
 
 static void
