@@ -1,9 +1,9 @@
 /*
- *  Copyright (C) 2004 Adam Hooper
+ *  Copyright © 2004 Adam Hooper
  *
  *  Ported from Galeon:
- *      Copyright (C) 2002 Ricardo Fernández Pascual
- *      Copyright (C) 2004 Crispin Flowerday
+ *      Copyright © 2002 Ricardo Fernández Pascual
+ *      Copyright © 2004 Crispin Flowerday
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-select-stylesheet-extension.c,v 1.4 2005/01/28 22:30:25 chpe Exp $
+ *  $Id: ephy-select-stylesheet-extension.c,v 1.6 2006/09/13 19:01:33 chpe Exp $
  */
 
 #include "config.h"
@@ -51,7 +51,7 @@ ephy_select_stylesheet_extension_get_type (void)
 GType
 ephy_select_stylesheet_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphySelectStylesheetExtensionClass),
 		NULL, /* base_init */
@@ -64,7 +64,7 @@ ephy_select_stylesheet_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_select_stylesheet_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_select_stylesheet_extension_iface_init,
 		NULL,
