@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004 Crispin Flowerday
+ *  Copyright © 2004 Crispin Flowerday
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id$
+ *  $Id: sidebar-commands.h,v 1.2 2006/09/13 19:01:36 chpe Exp $
  */
 
 #ifndef SIDEBAR_COMMANDS_H
@@ -39,10 +39,6 @@ void sidebar_cmd_download_link_as	(GtkAction *action,
 					 EphySidebarEmbed *window);
 void sidebar_cmd_save_image_as		(GtkAction *action,
 					 EphySidebarEmbed *window);
-void sidebar_cmd_copy_email_address	(GtkAction *action,
-				   	 EphySidebarEmbed *window);
-void sidebar_cmd_open_email_link	(GtkAction *action,
-					 EphySidebarEmbed *sbembed);
 
 G_END_DECLS
 
